@@ -16,7 +16,16 @@ def resample(infile,target_amplerate,outfile=None):
     if fs == target_amplerate:
         return infile
     #uint64_t Resample_s16(const int16_t *input, int16_t *output, int inSampleRate, int outSampleRate, uint64_t inputSize,uint32_t channels)
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/resampler.dll')
+
+    import platform
+    #mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    print(cur_paltform)
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/resampler.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/resampler.dylib')
+    print(mydll)
     if outfile is None:
         outfile = infile[:-4] +'_' +str(target_amplerate) + '.wav'
     infile_ref = c_char_p(bytes(infile.encode('utf-8')))
