@@ -13,7 +13,15 @@ class delaystruct(Structure):
 
 def cal_delay(reffile, testfile, samplerate):
         delays = delaystruct()
-        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/time_align.dll')
+
+        import platform
+        mydll = None
+        cur_paltform = platform.platform().split('-')[0]
+        if cur_paltform == 'Windows':
+            mydll = ctypes.windll.LoadLibrary(sys.prefix + '/time_align.dll')
+        if cur_paltform == 'macOS':
+            mydll = CDLL(sys.prefix + '/time_align.dylib')
+
         inputFile = c_char_p(
                bytes(reffile.encode('utf-8')))  # create_unicode_buffer(inFile.encode('utf-8'), len(inFile))
         outputFile = c_char_p(
